import { ConfirmOptions } from '@safecoin/web3.js';
import { TransactionBuilder } from '@/utils';
import { Operation, OperationHandler, Signer } from '@/types';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse, Bid } from '../models';
declare const Key: "CancelBidOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const cancelBidOperation: import("@/types").OperationConstructor<CancelBidOperation, "CancelBidOperation", CancelBidInput, CancelBidOutput>;
/**
 * @group Operations
 * @category Types
 */
export type CancelBidOperation = Operation<typeof Key, CancelBidInput, CancelBidOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type CancelBidInput = {
    auctioneerAuthority?: Signer;
    auctionHouse: Pick<AuctionHouse, 'authorityAddress' | 'address' | 'feeAccountAddress' | 'hasAuctioneer'>;
    bid: Pick<Bid, 'asset' | 'buyerAddress' | 'isPublic' | 'price' | 'receiptAddress' | 'tokens' | 'tradeStateAddress'>;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type CancelBidOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const cancelBidOperationHandler: OperationHandler<CancelBidOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type CancelBidBuilderParams = Omit<CancelBidInput, 'confirmOptions'> & {
    instructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type CancelBidBuilderContext = Omit<CancelBidOutput, 'response'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const cancelBidBuilder: (params: CancelBidBuilderParams) => TransactionBuilder<CancelBidBuilderContext>;
export {};
