import { ConfirmOptions } from '@safecoin/web3.js';
import { TransactionBuilder } from '@/utils';
import { Operation, OperationHandler, Signer } from '@/types';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse, Listing } from '../models';
declare const Key: "CancelListingOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const cancelListingOperation: import("@/types").OperationConstructor<CancelListingOperation, "CancelListingOperation", CancelListingInput, CancelListingOutput>;
/**
 * @group Operations
 * @category Types
 */
export type CancelListingOperation = Operation<typeof Key, CancelListingInput, CancelListingOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type CancelListingInput = {
    auctioneerAuthority?: Signer;
    auctionHouse: Pick<AuctionHouse, 'address' | 'authorityAddress' | 'feeAccountAddress' | 'hasAuctioneer'>;
    listing: Pick<Listing, 'asset' | 'price' | 'receiptAddress' | 'sellerAddress' | 'tokens' | 'tradeStateAddress'>;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type CancelListingOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const cancelListingOperationHandler: OperationHandler<CancelListingOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type CancelListingBuilderParams = Omit<CancelListingInput, 'confirmOptions'> & {
    instructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type CancelListingBuilderContext = Omit<CancelListingOutput, 'response'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const cancelListingBuilder: (params: CancelListingBuilderParams) => TransactionBuilder<CancelListingBuilderContext>;
export {};
