import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import { AuthorityScope } from '@safecoin/lpl-auction-house';
import type { Metaplex } from '@/Metaplex';
import { Operation, Signer, OperationHandler, Pda } from '@/types';
import { TransactionBuilder } from '@/utils';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse } from '../models/AuctionHouse';
declare const Key: "CreateAuctionHouseOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const createAuctionHouseOperation: import("@/types").OperationConstructor<CreateAuctionHouseOperation, "CreateAuctionHouseOperation", CreateAuctionHouseInput, CreateAuctionHouseOutput>;
/**
 * @group Operations
 * @category Types
 */
export type CreateAuctionHouseOperation = Operation<typeof Key, CreateAuctionHouseInput, CreateAuctionHouseOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type CreateAuctionHouseInput = {
    sellerFeeBasisPoints: number;
    requiresSignOff?: boolean;
    canChangeSalePrice?: boolean;
    auctioneerScopes?: AuthorityScope[];
    treasuryMint?: PublicKey;
    payer?: Signer;
    authority?: PublicKey | Signer;
    feeWithdrawalDestination?: PublicKey;
    treasuryWithdrawalDestinationOwner?: PublicKey;
    auctioneerAuthority?: PublicKey;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type CreateAuctionHouseOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
    auctionHouseAddress: Pda;
    auctionHouseFeeAccountAddress: Pda;
    auctionHouseTreasuryAddress: Pda;
    treasuryWithdrawalDestinationAddress: PublicKey;
    auctionHouse: AuctionHouse;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const createAuctionHouseOperationHandler: OperationHandler<CreateAuctionHouseOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type CreateAuctionHouseBuilderParams = Omit<CreateAuctionHouseInput, 'confirmOptions'> & {
    instructionKey?: string;
    delegateAuctioneerInstructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type CreateAuctionHouseBuilderContext = Omit<CreateAuctionHouseOutput, 'response' | 'auctionHouse'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const createAuctionHouseBuilder: (metaplex: Metaplex, params: CreateAuctionHouseBuilderParams) => TransactionBuilder<CreateAuctionHouseBuilderContext>;
export {};
