import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import type { Metaplex } from '@/Metaplex';
import { TransactionBuilder, Option } from '@/utils';
import { Operation, OperationHandler, Signer, SolAmount, SplTokenAmount, Pda } from '@/types';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse, Bid } from '../models';
declare const Key: "CreateBidOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const createBidOperation: import("@/types").OperationConstructor<CreateBidOperation, "CreateBidOperation", CreateBidInput, CreateBidOutput>;
/**
 * @group Operations
 * @category Types
 */
export type CreateBidOperation = Operation<typeof Key, CreateBidInput, CreateBidOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type CreateBidInput = {
    auctionHouse: AuctionHouse;
    buyer?: PublicKey | Signer;
    authority?: PublicKey | Signer;
    auctioneerAuthority?: Signer;
    mintAccount: PublicKey;
    seller?: Option<PublicKey>;
    tokenAccount?: Option<PublicKey>;
    price?: SolAmount | SplTokenAmount;
    tokens?: SplTokenAmount;
    bookkeeper?: Signer;
    printReceipt?: boolean;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type CreateBidOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
    buyerTradeState: Pda;
    tokenAccount: Option<PublicKey>;
    metadata: Pda;
    buyer: PublicKey;
    receipt: Option<Pda>;
    bookkeeper: Option<PublicKey>;
    price: SolAmount | SplTokenAmount;
    tokens: SplTokenAmount;
    bid: Bid;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const createBidOperationHandler: OperationHandler<CreateBidOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type CreateBidBuilderParams = Omit<CreateBidInput, 'confirmOptions'> & {
    instructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type CreateBidBuilderContext = Omit<CreateBidOutput, 'response' | 'bid'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const createBidBuilder: (metaplex: Metaplex, params: CreateBidBuilderParams) => Promise<TransactionBuilder<CreateBidBuilderContext>>;
export {};
