import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import type { Metaplex } from '@/Metaplex';
import type { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { Operation, OperationHandler, Signer, Pda, SolAmount, SplTokenAmount } from '@/types';
import { TransactionBuilder, Option } from '@/utils';
import { AuctionHouse, Listing } from '../models';
declare const Key: "CreateListingOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const createListingOperation: import("@/types").OperationConstructor<CreateListingOperation, "CreateListingOperation", CreateListingInput, CreateListingOutput>;
/**
 * @group Operations
 * @category Types
 */
export type CreateListingOperation = Operation<typeof Key, CreateListingInput, CreateListingOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type CreateListingInput = {
    auctionHouse: AuctionHouse;
    payer?: Signer;
    seller?: PublicKey | Signer;
    authority?: PublicKey | Signer;
    auctioneerAuthority?: Signer;
    mintAccount: PublicKey;
    tokenAccount?: PublicKey;
    price?: SolAmount | SplTokenAmount;
    tokens?: SplTokenAmount;
    bookkeeper?: Signer;
    printReceipt?: boolean;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type CreateListingOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
    sellerTradeState: Pda;
    freeSellerTradeState: Pda;
    tokenAccount: PublicKey;
    metadata: Pda;
    seller: PublicKey;
    receipt: Option<Pda>;
    bookkeeper: Option<PublicKey>;
    price: SolAmount | SplTokenAmount;
    tokens: SplTokenAmount;
    listing: Listing;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const createListingOperationHandler: OperationHandler<CreateListingOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type CreateListingBuilderParams = Omit<CreateListingInput, 'confirmOptions'> & {
    instructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type CreateListingBuilderContext = Omit<CreateListingOutput, 'response' | 'listing'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const createListingBuilder: (metaplex: Metaplex, params: CreateListingBuilderParams) => TransactionBuilder<CreateListingBuilderContext>;
export {};
