import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import type { Metaplex } from '@/Metaplex';
import { TransactionBuilder, Option } from '@/utils';
import { Operation, OperationHandler, Pda, Signer, SolAmount, SplTokenAmount } from '@/types';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse, Bid, Listing, Purchase } from '../models';
declare const Key: "ExecuteSaleOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const executeSaleOperation: import("@/types").OperationConstructor<ExecuteSaleOperation, "ExecuteSaleOperation", ExecuteSaleInput, ExecuteSaleOutput>;
/**
 * @group Operations
 * @category Types
 */
export type ExecuteSaleOperation = Operation<typeof Key, ExecuteSaleInput, ExecuteSaleOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type ExecuteSaleInput = {
    bid: Pick<Bid, 'asset' | 'auctionHouse' | 'buyerAddress' | 'canceledAt' | 'price' | 'receiptAddress' | 'tokens' | 'tradeStateAddress'>;
    listing: Pick<Listing, 'asset' | 'auctionHouse' | 'canceledAt' | 'sellerAddress' | 'tradeStateAddress' | 'receiptAddress'>;
    auctionHouse: AuctionHouse;
    auctioneerAuthority?: Signer;
    bookkeeper?: Signer;
    printReceipt?: boolean;
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type ExecuteSaleOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
    sellerTradeState: PublicKey;
    buyerTradeState: PublicKey;
    buyer: PublicKey;
    seller: PublicKey;
    metadata: PublicKey;
    bookkeeper: Option<PublicKey>;
    receipt: Option<Pda>;
    price: SolAmount | SplTokenAmount;
    tokens: SplTokenAmount;
    purchase: Purchase;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const executeSaleOperationHandler: OperationHandler<ExecuteSaleOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type ExecuteSaleBuilderParams = Omit<ExecuteSaleInput, 'confirmOptions'> & {
    instructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Contexts
 */
export type ExecuteSaleBuilderContext = Omit<ExecuteSaleOutput, 'response' | 'purchase'>;
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const executeSaleBuilder: (metaplex: Metaplex, params: ExecuteSaleBuilderParams) => TransactionBuilder<ExecuteSaleBuilderContext>;
export {};
