import { ConfirmOptions, PublicKey } from '@safecoin/web3.js';
import { AuthorityScope } from '@safecoin/lpl-auction-house';
import type { Metaplex } from '@/Metaplex';
import { Operation, Signer, OperationHandler } from '@/types';
import { TransactionBuilder } from '@/utils';
import { SendAndConfirmTransactionResponse } from '../../rpcModule';
import { AuctionHouse } from '../models/AuctionHouse';
declare const Key: "UpdateAuctionHouseOperation";
/**
 * @group Operations
 * @category Constructors
 */
export declare const updateAuctionHouseOperation: import("@/types").OperationConstructor<UpdateAuctionHouseOperation, "UpdateAuctionHouseOperation", UpdateAuctionHouseInput, UpdateAuctionHouseOutput>;
/**
 * @group Operations
 * @category Types
 */
export type UpdateAuctionHouseOperation = Operation<typeof Key, UpdateAuctionHouseInput, UpdateAuctionHouseOutput>;
/**
 * @group Operations
 * @category Inputs
 */
export type UpdateAuctionHouseInput = {
    auctionHouse: AuctionHouse;
    authority?: Signer;
    payer?: Signer;
    sellerFeeBasisPoints?: number | null;
    requiresSignOff?: boolean | null;
    canChangeSalePrice?: boolean | null;
    newAuthority?: PublicKey;
    feeWithdrawalDestination?: PublicKey;
    treasuryWithdrawalDestinationOwner?: PublicKey;
    auctioneerAuthority?: PublicKey;
    auctioneerScopes?: AuthorityScope[];
    /** A set of options to configure how the transaction is sent and confirmed. */
    confirmOptions?: ConfirmOptions;
};
/**
 * @group Operations
 * @category Outputs
 */
export type UpdateAuctionHouseOutput = {
    /** The blockchain response from sending and confirming the transaction. */
    response: SendAndConfirmTransactionResponse;
    auctionHouse: AuctionHouse;
};
/**
 * @group Operations
 * @category Handlers
 */
export declare const updateAuctionHouseOperationHandler: OperationHandler<UpdateAuctionHouseOperation>;
/**
 * @group Transaction Builders
 * @category Inputs
 */
export type UpdateAuctionHouseBuilderParams = Omit<UpdateAuctionHouseInput, 'confirmOptions'> & {
    instructionKey?: string;
    delegateAuctioneerInstructionKey?: string;
    updateAuctioneerInstructionKey?: string;
};
/**
 * @group Transaction Builders
 * @category Constructors
 */
export declare const updateAuctionHouseBuilder: (metaplex: Metaplex, params: UpdateAuctionHouseBuilderParams) => TransactionBuilder;
export {};
