/// <reference types="node" />
import { PublicKey } from '@safecoin/web3.js';
import { Buffer } from 'buffer';
export type Account<T> = {
    readonly publicKey: PublicKey;
    readonly executable: boolean;
    readonly owner: PublicKey;
    readonly lamports: number;
    readonly data: T;
    readonly rentEpoch?: number;
};
export type MaybeAccount<T> = (Account<T> & {
    readonly exists: true;
}) | {
    readonly publicKey: PublicKey;
    readonly exists: false;
};
export type UnparsedAccount = Account<Buffer>;
export type UnparsedMaybeAccount = MaybeAccount<Buffer>;
export type AccountParser<T> = {
    name: string;
    deserialize: (data: Buffer, offset?: number) => [T, number];
};
export type AccountParsingFunction<T> = {
    (unparsedAccount: UnparsedAccount): Account<T>;
    (unparsedAccount: UnparsedMaybeAccount): MaybeAccount<T>;
};
export type AccountParsingAndAssertingFunction<T> = (unparsedAccount: UnparsedAccount | UnparsedMaybeAccount, solution?: string) => Account<T>;
export declare function parseAccount<T>(account: UnparsedMaybeAccount, parser: AccountParser<T>): MaybeAccount<T>;
export declare function parseAccount<T>(account: UnparsedAccount, parser: AccountParser<T>): Account<T>;
export declare function getAccountParsingFunction<T>(parser: AccountParser<T>): AccountParsingFunction<T>;
export declare function toAccount<T>(account: UnparsedAccount | UnparsedMaybeAccount, parser: AccountParser<T>, solution?: string): Account<T>;
export declare function getAccountParsingAndAssertingFunction<T>(parser: AccountParser<T>): AccountParsingAndAssertingFunction<T>;
export declare function assertAccountExists<T>(account: MaybeAccount<T>, name?: string, solution?: string): asserts account is Account<T> & {
    exists: true;
};
